@@ -39,10 +39,10 @@ var NAVTREEINDEX12 =
 "group__reduce__func__max.htm#ga27a8604de959200acd69d20dbede1e32":[2,1,137,5],
 "group__reduce__func__max.htm#ga4459daf5a3b081fb4ee15eb49d8c902a":[2,1,137,4],
 "group__reduce__func__max.htm#ga4459daf5a3b081fb4ee15eb49d8c902a":[2,0,11,2,3,4],
-"group__reduce__func__max.htm#ga5f71ab6056943723149585d2aebade7c":[2,1,137,3],
 "group__reduce__func__max.htm#ga5f71ab6056943723149585d2aebade7c":[2,0,11,2,3,3],
-"group__reduce__func__max.htm#gab0de5929db14a2449c935ed82acf5153":[2,0,11,2,3,7],
+"group__reduce__func__max.htm#ga5f71ab6056943723149585d2aebade7c":[2,1,137,3],
 "group__reduce__func__max.htm#gab0de5929db14a2449c935ed82acf5153":[2,1,137,7],
+"group__reduce__func__max.htm#gab0de5929db14a2449c935ed82acf5153":[2,0,11,2,3,7],
 "group__reduce__func__max.htm#gaea009bd51145be2fcc688b2390725401":[2,0,11,2,3,1],
 "group__reduce__func__max.htm#gaea009bd51145be2fcc688b2390725401":[2,1,137,1],
 "group__reduce__func__max.htm#gaf0e6a523e2e435d5409d5d8cb843d8a2":[2,0,11,2,3,0],
@@ -87,8 +87,8 @@ var NAVTREEINDEX12 =
 "group__reduce__func__product.htm#gaca78d54c53a33b419bfdb5c64accbc7b":[2,0,11,2,5,3],
 "group__reduce__func__product.htm#gad226a6ec77c12fd16cf42e3fe3264e22":[2,1,167,1],
 "group__reduce__func__product.htm#gad226a6ec77c12fd16cf42e3fe3264e22":[2,0,11,2,5,1],
-"group__reduce__func__sum.htm":[2,1,227],
 "group__reduce__func__sum.htm":[2,0,11,2,6],
+"group__reduce__func__sum.htm":[2,1,227],
 "group__reduce__func__sum.htm#ga2176b9ffbc6038cf6cebb19aa7736793":[2,0,11,2,6,5],
 "group__reduce__func__sum.htm#ga2176b9ffbc6038cf6cebb19aa7736793":[2,1,227,5],
 "group__reduce__func__sum.htm#ga27080996b6ea1c422f16da4b06fb76a7":[2,0,11,2,6,6],
@@ -201,8 +201,8 @@ var NAVTREEINDEX12 =
 "group__signal__func__fft.htm#ga1a47710d5128c3e4ffa79b00d9b5c1d0":[2,0,8,1,0,10],
 "group__signal__func__fft.htm#ga291b032096457e725fa6bcd2e9b3ce30":[2,1,70,5],
 "group__signal__func__fft.htm#ga291b032096457e725fa6bcd2e9b3ce30":[2,0,8,1,0,5],
-"group__signal__func__fft.htm#ga4ddef19b43d9a50c97b1a835df60279a":[2,1,70,2],
 "group__signal__func__fft.htm#ga4ddef19b43d9a50c97b1a835df60279a":[2,0,8,1,0,2],
+"group__signal__func__fft.htm#ga4ddef19b43d9a50c97b1a835df60279a":[2,1,70,2],
 "group__signal__func__fft.htm#ga64d0db9e59c9410ba738591ad146a884":[2,0,8,1,0,0],
 "group__signal__func__fft.htm#ga64d0db9e59c9410ba738591ad146a884":[2,1,70,0],
 "group__signal__func__fft.htm#ga6e082e788e1085ae5e39794ddade9913":[2,1,70,3],
@@ -213,8 +213,8 @@ var NAVTREEINDEX12 =
 "group__signal__func__fft.htm#ga7d171d51c68b8280a0219ab42170f46d":[2,0,8,1,0,7],
 "group__signal__func__fft.htm#ga8b445e474508d96da691a9608dec5403":[2,0,8,1,0,6],
 "group__signal__func__fft.htm#ga8b445e474508d96da691a9608dec5403":[2,1,70,6],
-"group__signal__func__fft.htm#ga9c64e0a83ceaed1de1d5b6a32750653a":[2,0,8,1,0,8],
 "group__signal__func__fft.htm#ga9c64e0a83ceaed1de1d5b6a32750653a":[2,1,70,8],
+"group__signal__func__fft.htm#ga9c64e0a83ceaed1de1d5b6a32750653a":[2,0,8,1,0,8],
 "group__signal__func__fft.htm#ga9e03a61224c7b9d217b0099ce1d5be3a":[2,0,8,1,0,9],
 "group__signal__func__fft.htm#ga9e03a61224c7b9d217b0099ce1d5be3a":[2,1,70,9],
 "group__signal__func__fft.htm#gaa2f03c9ee1cb80dc184c0b0a13176da1":[2,1,70,1],
@@ -249,5 +249,5 @@ var NAVTREEINDEX12 =
 "group__signal__func__fft__c2r.htm":[2,0,8,1,3],
 "group__signal__func__fft__c2r.htm#ga01fa22566a246623a7378960e4ac06a3":[2,0,8,1,3,3],
 "group__signal__func__fft__c2r.htm#ga01fa22566a246623a7378960e4ac06a3":[2,1,73,3],
-"group__signal__func__fft__c2r.htm#gaa5efdfd84213a4a07d81a5d534cde5ac":[2,0,8,1,3,2]
+"group__signal__func__fft__c2r.htm#gaa5efdfd84213a4a07d81a5d534cde5ac":[2,1,73,2]
 };
