@@ -1,16 +1,16 @@
 var NAVTREEINDEX13 =
 {
-"group__signal__func__fft__c2r.htm#gaa5efdfd84213a4a07d81a5d534cde5ac":[2,1,73,2],
-"group__signal__func__fft__c2r.htm#gaa9b3322d9ffab15268919e1f114bed24":[2,0,8,1,3,1],
+"group__signal__func__fft__c2r.htm#gaa5efdfd84213a4a07d81a5d534cde5ac":[2,0,8,1,3,2],
 "group__signal__func__fft__c2r.htm#gaa9b3322d9ffab15268919e1f114bed24":[2,1,73,1],
+"group__signal__func__fft__c2r.htm#gaa9b3322d9ffab15268919e1f114bed24":[2,0,8,1,3,1],
 "group__signal__func__fft__c2r.htm#gaaa7da16f226cacaffced631e08da4493":[2,0,8,1,3,0],
 "group__signal__func__fft__c2r.htm#gaaa7da16f226cacaffced631e08da4493":[2,1,73,0],
 "group__signal__func__fft__convolve.htm":[2,1,74],
 "group__signal__func__fft__convolve.htm":[2,0,8,0,4],
 "group__signal__func__fft__convolve.htm#ga711d2440b2d954215a02d90ac8952af8":[2,1,74,0],
 "group__signal__func__fft__convolve.htm#ga711d2440b2d954215a02d90ac8952af8":[2,0,8,0,4,0],
-"group__signal__func__fft__convolve2.htm":[2,0,8,0,5],
 "group__signal__func__fft__convolve2.htm":[2,1,75],
+"group__signal__func__fft__convolve2.htm":[2,0,8,0,5],
 "group__signal__func__fft__convolve2.htm#ga9144b146cb6c74da32eb75fdf3570b27":[2,1,75,1],
 "group__signal__func__fft__convolve2.htm#ga9144b146cb6c74da32eb75fdf3570b27":[2,0,8,0,5,1],
 "group__signal__func__fft__convolve2.htm#gab52ebe631d8358cdef1b5c8a95550556":[2,1,75,0],
@@ -31,20 +31,20 @@ var NAVTREEINDEX13 =
 "group__signal__func__fft__r2c.htm#gab4ca074b54218b74d8cfbda63d38be51":[2,0,8,1,4,1],
 "group__signal__func__fft__r2c.htm#gaecfef8da267bdc9bddb802badf0d1da3":[2,1,77,3],
 "group__signal__func__fft__r2c.htm#gaecfef8da267bdc9bddb802badf0d1da3":[2,0,8,1,4,3],
-"group__signal__func__fir.htm":[2,1,78],
 "group__signal__func__fir.htm":[2,0,8,2,0],
+"group__signal__func__fir.htm":[2,1,78],
 "group__signal__func__fir.htm#ga2a850e69775eede4709e0d607bba240b":[2,0,8,2,0,0],
 "group__signal__func__fir.htm#ga2a850e69775eede4709e0d607bba240b":[2,1,78,0],
 "group__signal__func__fir.htm#gac80d4c15f750d3b70c31748c329e1282":[2,0,8,2,0,1],
 "group__signal__func__fir.htm#gac80d4c15f750d3b70c31748c329e1282":[2,1,78,1],
 "group__signal__func__ifft.htm":[2,0,8,1,5],
 "group__signal__func__ifft.htm":[2,1,108],
-"group__signal__func__ifft.htm#ga2d62c120b474b3b937b0425c994645fe":[2,1,108,0],
 "group__signal__func__ifft.htm#ga2d62c120b474b3b937b0425c994645fe":[2,0,8,1,5,0],
+"group__signal__func__ifft.htm#ga2d62c120b474b3b937b0425c994645fe":[2,1,108,0],
 "group__signal__func__ifft.htm#ga5cee5baba1961e509d4235dcd80c4073":[2,0,8,1,5,3],
 "group__signal__func__ifft.htm#ga5cee5baba1961e509d4235dcd80c4073":[2,1,108,3],
-"group__signal__func__ifft.htm#ga827379bef0e2cadb382c1b6301c91429":[2,0,8,1,5,1],
 "group__signal__func__ifft.htm#ga827379bef0e2cadb382c1b6301c91429":[2,1,108,1],
+"group__signal__func__ifft.htm#ga827379bef0e2cadb382c1b6301c91429":[2,0,8,1,5,1],
 "group__signal__func__ifft.htm#gaf63a9f9f549c8f660d0b27294d9ba37a":[2,0,8,1,5,4],
 "group__signal__func__ifft.htm#gaf63a9f9f549c8f660d0b27294d9ba37a":[2,1,108,4],
 "group__signal__func__ifft.htm#gaf78b830b324704ae7c96e7e608502963":[2,0,8,1,5,2],
@@ -67,8 +67,8 @@ var NAVTREEINDEX13 =
 "group__signal__func__ifft3.htm#ga133593d11131b304a3692048355f78e7":[2,1,110,3],
 "group__signal__func__ifft3.htm#ga439a7a49723bc6cf77cf4fe7f8dfe334":[2,0,8,1,7,1],
 "group__signal__func__ifft3.htm#ga439a7a49723bc6cf77cf4fe7f8dfe334":[2,1,110,1],
-"group__signal__func__ifft3.htm#gadb26d2805d8b62f2ed44145502c4ee4d":[2,1,110,2],
 "group__signal__func__ifft3.htm#gadb26d2805d8b62f2ed44145502c4ee4d":[2,0,8,1,7,2],
+"group__signal__func__ifft3.htm#gadb26d2805d8b62f2ed44145502c4ee4d":[2,1,110,2],
 "group__signal__func__ifft3.htm#gae00c56fdd3efc957da9ec84c2bdaa64f":[2,1,110,4],
 "group__signal__func__ifft3.htm#gae00c56fdd3efc957da9ec84c2bdaa64f":[2,0,8,1,7,4],
 "group__signal__func__ifft3.htm#gafdabcf20f793430134550e37f7a71bbd":[2,1,110,0],
@@ -84,8 +84,8 @@ var NAVTREEINDEX13 =
 "group__sort__func__sort.htm":[2,0,11,4,0],
 "group__sort__func__sort.htm#ga8d1a62b3e41bfcdeef810a442869b42c":[2,0,11,4,0,1],
 "group__sort__func__sort.htm#ga8d1a62b3e41bfcdeef810a442869b42c":[2,1,213,1],
-"group__sort__func__sort.htm#gac4460d605452515d07ee8432f906aa8e":[2,1,213,0],
 "group__sort__func__sort.htm#gac4460d605452515d07ee8432f906aa8e":[2,0,11,4,0,0],
+"group__sort__func__sort.htm#gac4460d605452515d07ee8432f906aa8e":[2,1,213,0],
 "group__sort__func__sort__index.htm":[2,1,215],
 "group__sort__func__sort__index.htm":[2,0,11,4,2],
 "group__sort__func__sort__index.htm#ga55675cd825c320db87398b1010b6ae41":[2,0,11,4,2,0],
@@ -104,8 +104,8 @@ var NAVTREEINDEX13 =
 "group__sparse__func__col__idx.htm":[2,0,6,5,3],
 "group__sparse__func__col__idx.htm#ga1960849b7d65a431216598d2752df46d":[2,1,218,1],
 "group__sparse__func__col__idx.htm#ga1960849b7d65a431216598d2752df46d":[2,0,6,5,3,1],
-"group__sparse__func__col__idx.htm#gaa62f2eaac514763e871e96a878155fb2":[2,0,6,5,3,0],
 "group__sparse__func__col__idx.htm#gaa62f2eaac514763e871e96a878155fb2":[2,1,218,0],
+"group__sparse__func__col__idx.htm#gaa62f2eaac514763e871e96a878155fb2":[2,0,6,5,3,0],
 "group__sparse__func__convert__to.htm":[2,1,217],
 "group__sparse__func__convert__to.htm":[2,0,6,5,2],
 "group__sparse__func__convert__to.htm#ga552d3a90dae9d2c6646a991100688162":[2,1,217,1],
@@ -120,14 +120,14 @@ var NAVTREEINDEX13 =
 "group__sparse__func__create.htm#ga52e3b2895cf9e9d697a06b4b44190d92":[2,1,216,1],
 "group__sparse__func__create.htm#ga9a0ae91eea18203041d9f9131dbb99cc":[2,1,216,2],
 "group__sparse__func__create.htm#ga9a0ae91eea18203041d9f9131dbb99cc":[2,0,6,5,1,2],
-"group__sparse__func__create.htm#gac0d367d8c9daf27b36a6981bbfcdb970":[2,1,216,5],
 "group__sparse__func__create.htm#gac0d367d8c9daf27b36a6981bbfcdb970":[2,0,6,5,1,5],
-"group__sparse__func__create.htm#gae4621e58bfaf6d80668309824fde86c0":[2,1,216,4],
+"group__sparse__func__create.htm#gac0d367d8c9daf27b36a6981bbfcdb970":[2,1,216,5],
 "group__sparse__func__create.htm#gae4621e58bfaf6d80668309824fde86c0":[2,0,6,5,1,4],
+"group__sparse__func__create.htm#gae4621e58bfaf6d80668309824fde86c0":[2,1,216,4],
 "group__sparse__func__create.htm#gae9a843c7e93b05e6b090ca32b271ebe9":[2,1,216,3],
 "group__sparse__func__create.htm#gae9a843c7e93b05e6b090ca32b271ebe9":[2,0,6,5,1,3],
-"group__sparse__func__dense.htm":[2,1,50],
 "group__sparse__func__dense.htm":[2,0,6,5,0],
+"group__sparse__func__dense.htm":[2,1,50],
 "group__sparse__func__dense.htm#ga1f39a8de17f18750bfe1ec8812a743a8":[2,0,6,5,0,1],
 "group__sparse__func__dense.htm#ga1f39a8de17f18750bfe1ec8812a743a8":[2,1,50,1],
 "group__sparse__func__dense.htm#ga80c3d8db78d537b74d9caebcf359b6a5":[2,0,6,5,0,0],
@@ -140,16 +140,16 @@ var NAVTREEINDEX13 =
 "group__sparse__func__info.htm#gae6b553df80e21c174d374e82d8505ba5":[2,1,219,0],
 "group__sparse__func__nnz.htm":[2,1,220],
 "group__sparse__func__nnz.htm":[2,0,6,5,5],
-"group__sparse__func__nnz.htm#ga0c1ad61d829c02a280c28820eb91f03e":[2,0,6,5,5,0],
 "group__sparse__func__nnz.htm#ga0c1ad61d829c02a280c28820eb91f03e":[2,1,220,0],
+"group__sparse__func__nnz.htm#ga0c1ad61d829c02a280c28820eb91f03e":[2,0,6,5,5,0],
 "group__sparse__func__nnz.htm#gaf36b9a489570cc007d1f99cc9bd6d41e":[2,1,220,1],
 "group__sparse__func__nnz.htm#gaf36b9a489570cc007d1f99cc9bd6d41e":[2,0,6,5,5,1],
 "group__sparse__func__row__idx.htm":[2,0,6,5,6],
 "group__sparse__func__row__idx.htm":[2,1,221],
-"group__sparse__func__row__idx.htm#ga12af820b694c32b1e81fd246ccc87d1e":[2,0,6,5,6,0],
 "group__sparse__func__row__idx.htm#ga12af820b694c32b1e81fd246ccc87d1e":[2,1,221,0],
-"group__sparse__func__row__idx.htm#ga3bda3d6aa334ea126b175a84d0b43d46":[2,0,6,5,6,1],
+"group__sparse__func__row__idx.htm#ga12af820b694c32b1e81fd246ccc87d1e":[2,0,6,5,6,0],
 "group__sparse__func__row__idx.htm#ga3bda3d6aa334ea126b175a84d0b43d46":[2,1,221,1],
+"group__sparse__func__row__idx.htm#ga3bda3d6aa334ea126b175a84d0b43d46":[2,0,6,5,6,1],
 "group__sparse__func__storage.htm":[2,0,6,5,7],
 "group__sparse__func__storage.htm":[2,1,222],
 "group__sparse__func__storage.htm#ga31299482afe241ef045f4d107033c999":[2,0,6,5,7,0],
@@ -158,8 +158,8 @@ var NAVTREEINDEX13 =
 "group__sparse__func__storage.htm#ga8d495f6f59420e7b9dbf33811aba046c":[2,0,6,5,7,1],
 "group__sparse__func__values.htm":[2,0,6,5,8],
 "group__sparse__func__values.htm":[2,1,223],
-"group__sparse__func__values.htm#ga4d913251cdbedbc48409c88ebddbe2fe":[2,1,223,0],
 "group__sparse__func__values.htm#ga4d913251cdbedbc48409c88ebddbe2fe":[2,0,6,5,8,0],
+"group__sparse__func__values.htm#ga4d913251cdbedbc48409c88ebddbe2fe":[2,1,223,0],
 "group__sparse__func__values.htm#gaf5c4ce9092dd3470480461d79b75d59d":[2,1,223,1],
 "group__sparse__func__values.htm#gaf5c4ce9092dd3470480461d79b75d59d":[2,0,6,5,8,1],
 "group__stat__func__corrcoef.htm":[2,0,9,0,0],
@@ -172,8 +172,8 @@ var NAVTREEINDEX13 =
 "group__stat__func__cov.htm":[2,1,48],
 "group__stat__func__cov.htm#ga1c1c9a1d919efb02729958a91666162f":[2,1,48,0],
 "group__stat__func__cov.htm#ga1c1c9a1d919efb02729958a91666162f":[2,0,9,0,1,0],
-"group__stat__func__cov.htm#ga8930d1c25039e0d6d645607115932cb6":[2,1,48,1],
 "group__stat__func__cov.htm#ga8930d1c25039e0d6d645607115932cb6":[2,0,9,0,1,1],
+"group__stat__func__cov.htm#ga8930d1c25039e0d6d645607115932cb6":[2,1,48,1],
 "group__stat__func__mean.htm":[2,0,9,0,2],
 "group__stat__func__mean.htm":[2,1,140],
 "group__stat__func__mean.htm#ga008221f09b128799b2382493916a4bc8":[2,1,140,2],
@@ -186,8 +186,8 @@ var NAVTREEINDEX13 =
 "group__stat__func__mean.htm#ga762600f4aa698a1de34ce72f7d4a0d89":[2,1,140,0],
 "group__stat__func__mean.htm#ga87fd44bb47e6ea6380ea8b7dadd2f4e8":[2,0,9,0,2,1],
 "group__stat__func__mean.htm#ga87fd44bb47e6ea6380ea8b7dadd2f4e8":[2,1,140,1],
-"group__stat__func__mean.htm#ga8cce333c8fc763d52464070ec9b3d825":[2,1,140,5],
 "group__stat__func__mean.htm#ga8cce333c8fc763d52464070ec9b3d825":[2,0,9,0,2,5],
+"group__stat__func__mean.htm#ga8cce333c8fc763d52464070ec9b3d825":[2,1,140,5],
 "group__stat__func__mean.htm#gaa09bbb576bce65d2de50ab99d1ccb341":[2,0,9,0,2,7],
 "group__stat__func__mean.htm#gaa09bbb576bce65d2de50ab99d1ccb341":[2,1,140,7],
 "group__stat__func__mean.htm#gaeee2bb2f141534453367753ff6f860ac":[2,1,140,6],
@@ -196,58 +196,58 @@ var NAVTREEINDEX13 =
 "group__stat__func__median.htm":[2,1,143],
 "group__stat__func__median.htm#ga20441bd881f48caa47a1fbe6f066d377":[2,0,9,0,3,2],
 "group__stat__func__median.htm#ga20441bd881f48caa47a1fbe6f066d377":[2,1,143,2],
-"group__stat__func__median.htm#ga79ced0d340f8cbebb9fd1e0e75b7ee9e":[2,1,143,0],
 "group__stat__func__median.htm#ga79ced0d340f8cbebb9fd1e0e75b7ee9e":[2,0,9,0,3,0],
-"group__stat__func__median.htm#ga82b3d518bb7838eb6795af4a92c08b92":[2,1,143,1],
+"group__stat__func__median.htm#ga79ced0d340f8cbebb9fd1e0e75b7ee9e":[2,1,143,0],
 "group__stat__func__median.htm#ga82b3d518bb7838eb6795af4a92c08b92":[2,0,9,0,3,1],
+"group__stat__func__median.htm#ga82b3d518bb7838eb6795af4a92c08b92":[2,1,143,1],
 "group__stat__func__median.htm#gaea933a2ea8e33f57a99437695f7a4bd6":[2,1,143,3],
 "group__stat__func__median.htm#gaea933a2ea8e33f57a99437695f7a4bd6":[2,0,9,0,3,3],
 "group__stat__func__stdev.htm":[2,1,225],
 "group__stat__func__stdev.htm":[2,0,9,0,4],
-"group__stat__func__stdev.htm#ga0fbb49ddd033b0fcabd58a64ce355806":[2,0,9,0,4,1],
 "group__stat__func__stdev.htm#ga0fbb49ddd033b0fcabd58a64ce355806":[2,1,225,1],
+"group__stat__func__stdev.htm#ga0fbb49ddd033b0fcabd58a64ce355806":[2,0,9,0,4,1],
 "group__stat__func__stdev.htm#ga3d81575f2edbddea880db838ebadaac7":[2,1,225,0],
 "group__stat__func__stdev.htm#ga3d81575f2edbddea880db838ebadaac7":[2,0,9,0,4,0],
-"group__stat__func__stdev.htm#ga55df1afccd27eba77725b7096173cf98":[2,0,9,0,4,3],
 "group__stat__func__stdev.htm#ga55df1afccd27eba77725b7096173cf98":[2,1,225,3],
-"group__stat__func__stdev.htm#gaaebaa1553ae823fd0229fc7e6abdf350":[2,0,9,0,4,2],
+"group__stat__func__stdev.htm#ga55df1afccd27eba77725b7096173cf98":[2,0,9,0,4,3],
 "group__stat__func__stdev.htm#gaaebaa1553ae823fd0229fc7e6abdf350":[2,1,225,2],
-"group__stat__func__topk.htm":[2,1,236],
+"group__stat__func__stdev.htm#gaaebaa1553ae823fd0229fc7e6abdf350":[2,0,9,0,4,2],
 "group__stat__func__topk.htm":[2,0,9,0,5],
+"group__stat__func__topk.htm":[2,1,236],
 "group__stat__func__topk.htm#gaa7fa372d9b69c9e245807f1d989bc32d":[2,0,9,0,5,1],
 "group__stat__func__topk.htm#gaa7fa372d9b69c9e245807f1d989bc32d":[2,1,236,1],
-"group__stat__func__topk.htm#gaea5a2a6aa11ce7d25f7a7c0ffadbdf51":[2,1,236,0],
 "group__stat__func__topk.htm#gaea5a2a6aa11ce7d25f7a7c0ffadbdf51":[2,0,9,0,5,0],
-"group__stat__func__var.htm":[2,1,245],
+"group__stat__func__topk.htm#gaea5a2a6aa11ce7d25f7a7c0ffadbdf51":[2,1,236,0],
 "group__stat__func__var.htm":[2,0,9,0,6],
+"group__stat__func__var.htm":[2,1,245],
 "group__stat__func__var.htm#ga06ad132cb12a5760c2058278456d041e":[2,1,245,3],
 "group__stat__func__var.htm#ga06ad132cb12a5760c2058278456d041e":[2,0,9,0,6,3],
-"group__stat__func__var.htm#ga26f83014829926e3112de3435a87ac1d":[2,0,9,0,6,2],
 "group__stat__func__var.htm#ga26f83014829926e3112de3435a87ac1d":[2,1,245,2],
+"group__stat__func__var.htm#ga26f83014829926e3112de3435a87ac1d":[2,0,9,0,6,2],
 "group__stat__func__var.htm#ga413fdb917be8f5173f8b5650a181a120":[2,0,9,0,6,4],
 "group__stat__func__var.htm#ga413fdb917be8f5173f8b5650a181a120":[2,1,245,4],
-"group__stat__func__var.htm#ga59baa7e073507920910e1c32ae1d8432":[2,0,9,0,6,1],
 "group__stat__func__var.htm#ga59baa7e073507920910e1c32ae1d8432":[2,1,245,1],
-"group__stat__func__var.htm#ga7782e8de146ef2e7816aa75448ef8648":[2,1,245,0],
+"group__stat__func__var.htm#ga59baa7e073507920910e1c32ae1d8432":[2,0,9,0,6,1],
 "group__stat__func__var.htm#ga7782e8de146ef2e7816aa75448ef8648":[2,0,9,0,6,0],
-"group__stat__func__var.htm#ga9532100bf99d1b9757250907b3d08917":[2,1,245,7],
+"group__stat__func__var.htm#ga7782e8de146ef2e7816aa75448ef8648":[2,1,245,0],
 "group__stat__func__var.htm#ga9532100bf99d1b9757250907b3d08917":[2,0,9,0,6,7],
+"group__stat__func__var.htm#ga9532100bf99d1b9757250907b3d08917":[2,1,245,7],
 "group__stat__func__var.htm#gac726bf9890ba505b8433477e26c8854c":[2,1,245,6],
 "group__stat__func__var.htm#gac726bf9890ba505b8433477e26c8854c":[2,0,9,0,6,6],
-"group__stat__func__var.htm#gad4405591505b482f9f40b697aca4be72":[2,1,245,5],
 "group__stat__func__var.htm#gad4405591505b482f9f40b697aca4be72":[2,0,9,0,6,5],
+"group__stat__func__var.htm#gad4405591505b482f9f40b697aca4be72":[2,1,245,5],
 "group__stats__mat.htm":[2,0,9],
-"group__stream__func__read.htm":[2,1,175],
 "group__stream__func__read.htm":[2,0,4,0,0],
-"group__stream__func__read.htm#ga276257d24b4be407b51f5be18c99faf7":[2,1,175,5],
+"group__stream__func__read.htm":[2,1,175],
 "group__stream__func__read.htm#ga276257d24b4be407b51f5be18c99faf7":[2,0,4,0,0,5],
+"group__stream__func__read.htm#ga276257d24b4be407b51f5be18c99faf7":[2,1,175,5],
 "group__stream__func__read.htm#ga31522b71beee2b1c06d49b5aa65a5c6f":[2,1,175,2],
 "group__stream__func__read.htm#ga31522b71beee2b1c06d49b5aa65a5c6f":[2,0,4,0,0,2],
 "group__stream__func__read.htm#ga47670590753282be28e85892f59e37ce":[2,1,175,4],
 "group__stream__func__read.htm#ga47670590753282be28e85892f59e37ce":[2,0,4,0,0,4],
-"group__stream__func__read.htm#ga8e0331b300f0b94ea9cc53606cf38278":[2,1,175,1],
 "group__stream__func__read.htm#ga8e0331b300f0b94ea9cc53606cf38278":[2,0,4,0,0,1],
-"group__stream__func__read.htm#gab01a9d75d67f2ecfccac53b02c900930":[2,0,4,0,0,0],
+"group__stream__func__read.htm#ga8e0331b300f0b94ea9cc53606cf38278":[2,1,175,1],
 "group__stream__func__read.htm#gab01a9d75d67f2ecfccac53b02c900930":[2,1,175,0],
+"group__stream__func__read.htm#gab01a9d75d67f2ecfccac53b02c900930":[2,0,4,0,0,0],
 "group__stream__func__read.htm#gaf78aa8f367fbd6f408e90f0851e0557a":[2,0,4,0,0,3]
 };
