@@ -8,16 +8,15 @@
  ********************************************************/
 
 #include <arrayfire.h>
-#include <cstdio>
 #include <math.h>
+#include <cstdio>
 
 using namespace af;
 
 static const int M = 30;
 static const int N = 2 * M;
 
-int main(int argc, char *argv[])
-{
+int main(int, char**) {
     try {
         // Initialize the kernel array just once
         af::info();
@@ -27,10 +26,11 @@ int main(int argc, char *argv[])
         const array x = iota(dim4(N, 1), dim4(1, N)) / M - 1;
         const array y = iota(dim4(1, N), dim4(N, 1)) / M - 1;
 
-        static float t=0;
-        while(!myWindow.close()) {
-            t+=0.07;
-            array z = 10*x*-abs(y) * cos(x*x*(y+t))+sin(y*(x+t))-1.5;
+        static float t = 0;
+        while (!myWindow.close()) {
+            t += 0.07;
+            array z = 10 * x * -abs(y) * cos(x * x * (y + t)) +
+                      sin(y * (x + t)) - 1.5;
             myWindow.surface(x, y, z);
         }
 
