@@ -13,17 +13,15 @@
 
 using namespace af;
 
-int main(int argc, char *argv[])
-{
+int main(int argc, char* argv[]) {
     try {
-
         // Select a device and display arrayfire info
         int device = argc > 1 ? atoi(argv[1]) : 0;
         af::setDevice(device);
         af::info();
 
-        int n = 5;
-        array t = randu(n, n);
+        int n    = 5;
+        array t  = randu(n, n);
         array in = matmulNT(t, t) + identity(n, n) * n;
         af_print(in);
 
